@@ -1,3 +1,5 @@
+//! `Read` trait and helpers to read bytes for the deserializer.
+
 #[cfg(feature = "std")]
 use crate::error::Error;
 #[cfg(feature = "std")]
@@ -5,14 +7,21 @@ use std::io;
 
 use crate::error::Result;
 
+/// Trait used by the `de::Deserializer` to read bytes.
 pub trait Read<'de> {
+    /// Consumes and returns the next read byte.
     fn next(&mut self) -> Option<Result<u8>>;
+    /// Returns the next byte but does not consume.
+    ///
+    /// Repeated peeks (with no `next()` call) should return the same byte.
     fn peek(&mut self) -> Option<Result<u8>>;
+    /// Returns the position in the stream of bytes.
     fn byte_offset(&self) -> usize;
 }
 
+/// A wrapper to implement this crate's `Read` trait for `std::io::Read` trait implementations.
 #[cfg(feature = "std")]
-pub(crate) struct IoRead<R>
+pub struct IoRead<R>
 where
     R: io::Read,
 {
@@ -26,6 +35,7 @@ impl<R> IoRead<R>
 where
     R: io::Read,
 {
+    /// Instantiates a new reader.
     pub fn new(reader: R) -> Self {
         IoRead {
             iter: reader.bytes(),
@@ -79,12 +89,14 @@ where
     }
 }
 
-pub(crate) struct SliceRead<'a> {
+/// A wrapper to implement this crate's `Read` trait for byte slices.
+pub struct SliceRead<'a> {
     slice: &'a [u8],
     byte_offset: usize,
 }
 
 impl<'a> SliceRead<'a> {
+    /// Instantiates a new reader.
     pub fn new(slice: &'a [u8]) -> Self {
         SliceRead {
             slice,
